function objective_function = estimation_f(param, f_type, display, global_param, T, numdraws, OBS, husband, actual_moments, epsilon_b, epsilon_f, v_b, v_f, unidraw, wage_idx, age, h_wage_par_chart) 
%estimation_f
%	T - number of periods
%	numdraws - number of random draws
%	OBS - number of observations
%	Author: Osnat Lifshitz
%	Date: 23-jun-10

global fitted_moments_out;
global actual_moments_out;
global adjust_T_for_year;

x_idx = get_global_param_idx(f_type);
global_param(x_idx) = param;

% Utility parameters: 	%source: eckstein wolpin 89	
alfa1  = global_param(1);	%1100;		% constant      ===========================
alfa2  = global_param(2);	%-0.0047;	% utility from consumption 
alfa3  = global_param(3);	%-1.15;		% return to work experience
alfa41 = global_param(4);	%-35.3;		% utility from young children =======================
alfa42 = global_param(6);	%-1.56;		% utility from old children
alfa5  = global_param(7);	%-9.56;		% utility from leisure when unmarried  ========================
alfa51  = global_param(8);	%-9.56;		% utility from schooling HSG % dead parameter - part of 1
alfa52  = global_param(9);	%-9.56;		% utility from schooling SC % dead parameter - part of 1
alfa53  = global_param(10);	%-9.56;		% utility from schooling CG % dead parameter - part of 1
alfa54  = global_param(11);	%-9.56;		% utility from schooling PC % dead parameter - part of 1
% Wage parameters	%source: eckstein wolpin 89	
beta1  = global_param(12);	%1.05;  	%constant	=======================
beta2  = global_param(13);	%0.024; 	%experience	
beta3  = global_param(14);	%-0.0002;	%exp^2	
beta41 = global_param(15);	%0.1;		%HSG - schooling	
beta42 = global_param(16);	%0.2;		%SC -schooling	
beta43 = global_param(17);	%0.3;		%CG - schooling	
beta44 = global_param(18);	%0.35;		%PC - schooling	
beta5  = global_param(19);	%0.1;		%trend parameter
% Job offer parameters	%source: lifshitz 04	
row0   = global_param(20);	%-1.525;    	%constant =======================
row11  = global_param(21);	%0.017;		% HSG -schooling
row12  = global_param(22);	%0.017;		% SC - schooling
row13  = global_param(23);	%0.017;		% CG - schooling
row14  = global_param(24);	%0.017;		% PC - schooling
row2   = global_param(25);	%0.04;		% work experience
row3   = global_param(26);	%2.915;		% previous period
row4   = global_param(27);	%2.915;		% work experience^2
%probability of getting  married - parameters	
m1 = global_param(28);		%2.3;		% -0.08; 	%constant
m2 = global_param(29);		%-0.0005;	%  0.09; 	%age
m3 = global_param(30);		%-3.8;		% -4.5; 	%divorced
m4 = global_param(31);		%-0.00001; 	% -0.001;	%age square
m5 = global_param(32);      % schooling - schooling=-1, 0 , 1 , 2 , 3 
%probability of another child parameters	%source: lifshitz 04 - with adjustments	
c1 = global_param(33);		%3.0480969e-001;	%1.2;        	%married/single	
c2 = global_param(34);		%-2.1407835;	%-0.08;    	% previous work state	
c3 = global_param(35);		%2.4261934e-002;	%0.00006; 	%age	
c4 = global_param(36);		%-2.7521523e-001;	%constant
c5 = global_param(37);		%-6.3042305e-004;	%-0.000002;  	%age square	
c6 = global_param(38);		%-2.0773857;	%-0.52; 	%number of children at household	
c7 = global_param(39);		%-6.0227123;	%-0.0009;    	%square number of children
c8 = global_param(40);		% schooling - schooling=-1, 0 , 1 , 2 , 3 
%probability of divorce parameters	%source: lifshitz 04 - with adjustments	
d0 = global_param(41);			%-2.0290310e-003;	%-0.002;   	%year of marriage^2
d1 = global_param(42);			%1.5516584e-001;	%0.13;  	%year of marriage	
d2 = global_param(43);			%-5.0016304e-001;	%-0.57; 	%number of children	
d3 = global_param(44);			%constant
d4 = global_param(45);			%1.1141240e-001;	%0.10711; 	%previous work state	
d5 = global_param(46);			%-1.6730177e-001;	%-0.19; 	% husband wage in previous period 	
d6 = global_param(47);			%schooling - schooling=-1, 0 , 1 , 2 , 3 
% random shocks variance-covariance matrix
sigma(1,1) = global_param(48);          %wage error    0.05;
sigma(2,2) = global_param(49);          %utility error 0.5;
sigma(2,1) = global_param(50);          %correlation   0.5;
sigma(1,2) = 0;

moment_12_factor = 1;

%setting parameters according to type - 1-emp 2-marr 3-div  4-7-y_kids 8-11-o_kids 12-wages 13-emp_m 14-emp_um
if (strcmp(f_type,'ro'))
	fitted_moments_idx = [1];
elseif (strcmp(f_type,'child'))
	fitted_moments_idx = [4:7];
elseif (strcmp(f_type,'alpha'))
	fitted_moments_idx = [1:2];
elseif (strcmp(f_type,'beta'))
	fitted_moments_idx = 12;
elseif (strcmp(f_type,'marriage'))
	fitted_moments_idx = 2;
elseif (strcmp(f_type,'school'))
	fitted_moments_idx =[13:14];
elseif (strcmp(f_type,'all'))
	fitted_moments_idx =[1:2];
else
	error(sprintf('unsupported type %s', f_type));
end

% beta = 0 - static model !!!
beta = 0;%0.9983;		% discount rate

%%%%%%%%%%%%%%%%%%
% INITIALIZATION %
%%%%%%%%%%%%%%%%%%
% utilities(f,t) is the current utility of the chosen option
utilities = zeros(OBS,T);
% EMAX dimensions are
%period, experience, number of young child ,number of old childn, martial status, husband experience, husband schooling husband emp, previous stete
EMAX = zeros(T,T+1,5,5,2,4,5,2,2);
%individual moments
marr_moment = zeros(OBS,T);
div_moment = zeros(OBS,T);
y_kids_moment = zeros(OBS,T,4);
o_kids_moment = zeros(OBS,T,4);
wages = ones(OBS,T).*-1;  % wages(f,t) is the wage if labor state is work
emp = zeros(OBS,T);
emp_m = zeros(OBS,T);
emp_um = zeros(OBS,T);
%average   moments
f_marr = zeros(T);
f_div = zeros(T);
f_y_kids = zeros(T,4);
f_o_kids = zeros(T,4);
f_wages = zeros(T,1);  % average_wages(t) is the average wage of workers in year t
f_emp = zeros(T); % emp is the proportion of employment in period t
f_emp_m = zeros(T); % emp is the proportion of employment in period t
f_emp_um = zeros(T); % emp is the proportion of employment in period t
%%%%%%%%%%%%%%%%%%%%%
% SOLVING BACKWARDS %
%%%%%%%%%%%%%%%%%%%%%
K = [0:T]; % experience vector
K_DRAWS = ones([numdraws 1])*K;
%personal characteristics
marr_stat = 0;
y_kids = 0;
o_kids = 0;
count_age = 0; %age of oldest  child under 6
schooling_chart = [-1 0 1 2 3];
schooling = schooling_chart(wage_idx);
HSD=0;      HSG=0;     SC=0;     CG=0;    PC=0;
if schooling==-1
	HSD=1;
    alfa1=-15287;
elseif schooling==0
	HSG=1;
elseif schooling==1
	SC=1;
elseif schooling==2
	CG=1;
else
	PC=1;
end

h_wage_par = h_wage_par_chart(wage_idx,:);

for t = T : -1 : 1 %TIME
	for N_Y = 0 : 3 %young children
		for N_O = 0 : 3 % old children
			for M = 0 : 1 % martial status
				for HE = [5,15,25,35] %husband experience 5,15,25,35
					for HS = 1:5 %husband schooling :HD,HG,SC, C
						for HW = 0:1 %husband working/ not working
							for prev_state = 0 : 1 % state loop
								emax = 0;
								% calculate the wage
								tmp1 = beta1 + beta2*K_DRAWS + beta3*K_DRAWS.^2 + beta5*t;
								tmp2 = (epsilon_b(:,t)*sigma(1,1))*ones([1 T+1]);
								wage = 2000.*exp(tmp1 + tmp2);
								%calculate husband wage
								H_HSD = 0; H_HSG = 0; H_SC = 0; H_CG = 0; H_PC = 0;
								if HS == 1
									H_HSD = 1;
								elseif HS == 2
									H_HSG = 1;
								elseif HS == 3
									H_SC = 1;
								elseif HS == 4
									H_CG = 1;
								else
								   H_PC = 1;
								end
								husband_wage = h_wage_par(1)*H_HSD+h_wage_par(2)*H_HSG+h_wage_par(3)*H_SC+h_wage_par(4)*H_CG+h_wage_par(5)*H_PC+h_wage_par(6)*HE+h_wage_par(7)*HE^2+h_wage_par(8)*t;
								husband_wage=2000.*exp(husband_wage);
								% calculate the utility of each choice			
								tmp3=(sigma(2,1)*epsilon_b(:,t)+ (sigma(2,2)*v_b(:,t)))*ones([1 T+1]);
								utility1 = alfa1+alfa5*(1-M) + (1+alfa2)*(wage + husband_wage*M*HW) + alfa3*K_DRAWS + alfa41*N_Y + alfa42*N_O + tmp3 ;
								%utility1(:,1) = NaN;
								utility2 = husband_wage*M*HW  + 0*K_DRAWS;
								%utility2(T+1) = NaN;
								% calculate the offer probabilities
								lamda1 = row0  + row2*K_DRAWS + row3*prev_state + row4*K_DRAWS.^2;
								prob = exp(lamda1) ./ (1+exp(lamda1));
								% calculate the value of each choice
								if t == T
									value1 = utility1(:,2:T+1);% + 8*K_DRAWS(:,2:T+1);
									value2 = utility2(:,1:T);
								else
									value1 = utility1(:,2:T+1) + ones([numdraws 1])*beta*EMAX(t+1 ,2:T+1, N_Y+1,N_O+1,M+1,HE,HS,HW+1,1);
									value2 = utility2(:,1:T) + ones([numdraws 1])*beta*EMAX(t+1, 1:T, N_Y+1,N_O+1,M+1,HE,HS,HW+1,2);
								end
								maxvalue = max(value1,value2);
								emax_draw = prob(:,1:T).*maxvalue + (1 - prob(:,1:T)).*value2;
								% emax is the average of emax_draw over the draws
								emax = mean(emax_draw);
								EMAX(t,1:T,N_Y+1,N_O+1,M+1,HE,HS,HW+1,prev_state+1) = emax;
							end % close the previous state loop
						end %close the husband working loop
					end %close the husband schooling loop
				end %close the husband experience loop
			end % close the marriage loop
		end % close the old children loop
	end % close the young children loop
end % close the time loop

%%%%%%%%%%%%%%%%%%%
% SOLVING FORWARD %
%%%%%%%%%%%%%%%%%%%
% repeat forward times to generalize the result of a specific sample
% Initialize state
moment2 = actual_moments(1,3:13);

for obs_i = 1 : OBS
	state = 0;
	if obs_i<OBS*moment2(1);
        k  = 0;
		prev_state=1;
    else
        k=0;
		prev_state=0;
    end
	HE = 5;
	HS = 1;
	HW = 0;
	count_age = 0; %the age of the oldest child under6
	count_age2 = 0; %the age of the 2nd oldest child under6
    count_age3 = 0; %the age of the 3rd oldest child under6
    year_married = 0;
    if obs_i<OBS*moment2(2);
		M=1;
	else
		M=0;
	end
	D=0;
	if obs_i<OBS*moment2(7);
    	y_kids=3;
		year_married=5;
        count_age=4;
		count_age2=2;
		count_age3=1;
	elseif obs_i>=OBS*moment2(7) & obs_i<OBS*(moment2(6)+moment2(7));
		y_kids=2;
		year_married=3;
		count_age=3;
		count_age2=1;	
	elseif obs_i>=OBS*(moment2(6)+moment2(7)) & obs_i<OBS*(moment2(5)+moment2(6)+moment2(7));
		y_kids=1;
		count_age=1;
		year_married=1;	
	else
    	y_kids=0;    
    end
	if obs_i<OBS*moment2(8);
	o_kids=0;
	else
	o_kids=1;
	year_married=7;
	end
	% Make choices for all periods
	for t = 1 : T
		% husbands cohort characteristics
		year=husband(t,1);
        P_HSD=husband(t,2);
		P_HSG=husband(t,3);
		P_SC=husband(t,4);
		P_CG=husband(t,5);
		P_10=husband(t,6);
		P_20=husband(t,7);
		P_30=husband(t,8);
		P_HW=husband(t,9);
		%unidraw = rand(OBS,T,7); %1-job offer, 2- marrige offer, 3-husband schooling, 4 - husband experience, 5-husband working, 6-new child, 7-divorce
		% LETS FIND A HUSBAND
        if M == 0
			M_prob = m1+m2*(age+t)+m3*D+m4*(age+t)^2+m5*schooling;
			prob = exp(M_prob) / (1+exp(M_prob));
			if unidraw(obs_i,t,2)<prob
				M = 1;
                D=0;
		        if unidraw(obs_i,t,3)<P_HSD%husband schooling
		            HS=1;
		        elseif unidraw(obs_i,t,3)>P_HSD & unidraw(obs_i,t,3)<P_HSG
		            HS=2;
		        elseif unidraw(obs_i,t,3)>P_HSG & unidraw(obs_i,t,3)<P_SC
		            HS=3;    
		        elseif unidraw(obs_i,t,3)>P_SC & unidraw(obs_i,t,3)<P_CG
		            HS=4;
                else
		            HS=5;
		        end
		        if unidraw(obs_i,t,4)<P_10%husband experience
		            HE=5;
		        elseif unidraw(obs_i,t,4)>P_10 & unidraw(obs_i,t,4)<P_20
		            HE=15;
		        elseif unidraw(obs_i,t,4)>P_20 & unidraw(obs_i,t,4)<P_30
		            HE=25;    
		        else
		            HE=35;
		        end
		        if unidraw(obs_i,t,5)<P_HW%husband working
		            HW=1;
		        end
			end
		end
		%check for another child
        c_lamda=c1*M+c2*prev_state+c3*(age+t)+c4+c5*(age+t)^2+c6*(y_kids+o_kids)+c7*(y_kids+o_kids)^2+c8*schooling;
		child_prob=exp(c_lamda) / (1+exp(c_lamda));
			if unidraw(obs_i,t,6) <child_prob & age+t<40 
			if y_kids<3
				y_kids=y_kids+1;
                if count_age==0
                    count_age=count_age+1;
                  elseif count_age2==0
                    count_age2=count_age2+1;
                  elseif count_age3==0
                    count_age3=count_age3+1;
		       end
           end
       else
           if y_kids~=0
			     count_age=count_age+1;
                 if count_age2~=0
                    count_age2=count_age2+1;
                    if count_age3~=0
						count_age3=count_age3+1;
                    end
		        end
			end
		end
		if count_age==6
			y_kids=y_kids-1;
		    if o_kids<3
				o_kids=o_kids+1;
			end
		    count_age=count_age2;
            count_age2=count_age3;
            count_age3=0;
		end
	    %calculate husband wage
		H_HSD=0;     H_HSG=0;    H_SC=0;    H_CG=0;    H_PC=0;
		if HS==1
			H_HSD=1;
		elseif HS==2
			H_HSG=1;
		elseif HS==3
			H_SC=1;
		elseif HS==4
			H_CG=1;
		else
		   H_PC=1;
		end
		husband_wage = h_wage_par(1)*H_HSD+h_wage_par(2)*H_HSG+h_wage_par(3)*H_SC+h_wage_par(4)*H_CG+h_wage_par(5)*H_PC+h_wage_par(6)*HE+h_wage_par(7)*HE^2+h_wage_par(8)*t;
		husband_wage=2000.*exp(husband_wage);
		%check for divorce
		d_lamda=d0*year_married^2+d1*year_married+d2*(y_kids+o_kids)+d3+d4*prev_state+d5*husband_wage*HW+d6*schooling;
		P_DIVORCE  = exp(d_lamda) / (1+exp(d_lamda));
		if unidraw(obs_i,t,7)<P_DIVORCE% 
			if M==1
				M=0;
				D=1;
				year_married=0;
			end
		end
        
		% calculate the wage
		wage = 2000.*exp(beta1 + beta2*k + beta3*k^2 +  beta5*t + epsilon_f(t,obs_i)*sigma(1,1));
	    % calculate the utility of each choice			
		tmp4=sigma(2,1)*epsilon_f(t,obs_i)+ sigma(2,2)*v_f(t,obs_i);
		utility1 = alfa1+alfa5*(1-M)+(1+alfa2)*(wage+husband_wage*M*HW)+alfa3*k+alfa41*y_kids+alfa42*o_kids + tmp4;
		utility2 = husband_wage*M*HW;
		
		% calculate the value of each choice
		if t == T
			value1 = utility1;
			value2 = utility2;
		else
		% t+1,k+2,y_kids+1,o_kids+1,marr_stat+1,HE,HS,HW+1,1
			value1 = utility1 + beta*EMAX(t+1,k+2,y_kids+1,o_kids+1,M+1,HE,HS,HW+1,1);
			value2 = utility2 + beta*EMAX(t+1,k+1,y_kids+1,o_kids+1,M+1,HE,HS,HW+1,2);
		end
		% check alternatives' availability
		% calculate the offer probabilities
		lamda1 = row0 + row2*k + row3*prev_state + row4*k^2;
		prob = exp(lamda1) / (1+exp(lamda1)) ;
	    if unidraw(obs_i,t,1) >prob
			value1 = -inf;
		end
		% choose the best possible option
		maxvalue = max([value1 value2]);
		if maxvalue == value1 %choose to work
			emp(obs_i,t) = 1;
			if M==1					%%%%%%%%%%
				emp_m(obs_i,t) = 1; %%%%%%%%%%
			else					%%%%%%%%%%
				emp_um(obs_i,t) = 1;%%%%%%%%%%
			end;					%%%%%%%%%%
			wages(obs_i,t) =wage;
			utilities(obs_i,t) = utility1;
	        prev_state=1;
	        k=k+1;
		elseif maxvalue == value2
			emp(obs_i,t) = 0;
			wages(obs_i,t) =-10000;
			utilities(obs_i,t) = utility2;
	        prev_state=0;
	    end;
        % saving the moments
        marr_moment(obs_i,t)=M;
        div_moment(obs_i,t)=D;
        y_kids_moment(obs_i,t,y_kids+1)=1;
        o_kids_moment(obs_i,t,o_kids+1)=1;
		if M==1
			year_married=year_married+1;
		end   
	end % close the time loop
end % close the obs loop

%%%%%%%%%%%%%%%%%%%
% RESULTS SUMMARY %
%%%%%%%%%%%%%%%%%%%
f_emp = [mean(emp)]';
f_emp_m = [sum(emp_m)]./[sum(marr_moment)];
f_emp_um = [sum(emp_um)]./[OBS - sum(marr_moment)];
f_emp_m = f_emp_m';
f_emp_um = f_emp_um';
f_marr = [mean(marr_moment)]';
f_div = [mean(div_moment)]';
f_y_kids = [mean(y_kids_moment(:,:,1)); mean(y_kids_moment(:,:,2));mean(y_kids_moment(:,:,3));mean(y_kids_moment(:,:,4))]';
f_o_kids = [mean(o_kids_moment(:,:,1)); mean(o_kids_moment(:,:,2));mean(o_kids_moment(:,:,3));mean(o_kids_moment(:,:,4))]';
for t =1:T
	for obs_i = 1 :OBS
		if wages(obs_i,t) >-10000
			f_wages(t) = f_wages(t) + wages(obs_i,t);
		end
	end
	f_wages(t) = f_wages(t) / (f_emp(t)*OBS+0.000001);
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%    ESTIMATION PROCESS - SGMM
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 12 moments vectors 1968-2007: 
% year emp_f married_f divorced_f child6_0 child6_1 child6_2 child6_3 child618_0 child618_1 child618_2 child618_3 real_wage_f

fitted_moments_m = [f_emp f_marr f_div  f_y_kids  f_o_kids  f_wages f_emp_m f_emp_um];
fitted_moments_m(12) = fitted_moments_m(12)*moment_12_factor;
actual_moments_idx = fitted_moments_idx + 2*ones(size(fitted_moments_idx));
moments = (actual_moments(1:T,actual_moments_idx) - fitted_moments_m(:,fitted_moments_idx)).^2;

if (strcmp(display,'text'))
	if adjust_T_for_year == 0 || wage_idx < 4
		%if length(fitted_moments_idx) == 1
		fitted_moments_out(wage_idx,:,:) = fitted_moments_m;
		actual_moments_out(wage_idx,:,:) = actual_moments(1:T,3:16);
			%fitted_moments_out2(:,wage_idx) = actual_moments(1:T,actual_moments_idx);
			%fitted_moments_out2(:,wage_idx) = fitted_moments_m(:,fitted_moments_idx(1));

        %else 
		%	fitted_moments_out1(:,wage_idx) = fitted_moments_m(:,fitted_moments_idx(1));
		%	fitted_moments_out2(:,wage_idx) = fitted_moments_m(:,fitted_moments_idx(2));
		%end
	else
		%if length(fitted_moments_idx) == 1
			fitted_moments_out(wage_idx,2:end,:) = fitted_moments_m;
			actual_moments_out(wage_idx,2:end,:) = actual_moments(1:T,3:16);
			%fitted_moments_out1(2:end,wage_idx) = fitted_moments_m(:,fitted_moments_idx(1));
			%fitted_moments_out1(1,wage_idx) = 0;
		%else 
			%fitted_moments_out1(2:end,wage_idx) = fitted_moments_m(:,fitted_moments_idx(1));
			%fitted_moments_out1(1,wage_idx) = 0;
			%fitted_moments_out2(2:end,wage_idx) = fitted_moments_m(:,fitted_moments_idx(2));
			%fitted_moments_out2(1,wage_idx) = 0;
		%end
    end
end

if (strcmp(display,'text'))
	small_std = find(std(moments) < 0.001);
	if (length(small_std) > 0)
		disp('there are moments with std smaller than 0.001');
	end
end

moment_weight=1./(std(moments)+0.0001);   
objective_function=sum(sum(moments).*moment_weight);
% save interim data to file
tmp = [fitted_moments_m(:,fitted_moments_idx) actual_moments(1:T,actual_moments_idx)];

if (strcmp(display,'graph'))
	for graph_idx = 1:length(fitted_moments_idx)
		figure;
		plot(fitted_moments_m(:,fitted_moments_idx(graph_idx)),'b.-');hold on;
		title(sprintf('%s params', f_type));
		xlabel('period');
		ylabel('moments');
		plot(actual_moments(1:T,actual_moments_idx(graph_idx)),'r.-');hold off;
		legend('fitted','actual');
		grid on;
	end
end

