
capture log close
drop _all

*************************************************************************
*****  This file creates couples' records from the CPS file for		*
*****  1962 - 2007. The male variables are labeled *_m and the		*
*****  female's are *_f.						*
*****  Input file:  CPS_march_6207_ind.dta				*
*****  Output file: CPS_march_6207_couples.dta				*
*************************************************************************

set more 1
set mem 600m 


log using "c:\cpslog2.log", replace

use "C:\Documents and Settings\Tali\My Documents\Female Labor Supply - Eckstein and Lifshitz\data files\CPS_march_6207_ind.dta", clear

tab  year

* keep heads of households and spouses (no secondary families)
keep if relation == 1 | relation == 3
tab  year

* drop households with more than one male or more than one female
gen      year_hh_sex = string(year) + house + string(sex)
sort     year_hh_sex
tab year if year_hh_sex == year_hh_sex[_n-1] | year_hh_sex == year_hh_sex[_n+1]
drop     if year_hh_sex == year_hh_sex[_n-1] | year_hh_sex == year_hh_sex[_n+1]
drop     year_hh_sex

tab year
sort year house
save "C:\temp\CPS_6207_clean.dta", replace

* create couples - female records with merge of male spouse (if exists)
keep if sex == 1
foreach var of varlist *	{ 
	rename `var' `var'_m
				}
rename year_m  year
rename house_m house
save "C:\temp\CPS_6207m.dta", replace

use "C:\temp\CPS_6207_clean.dta", clear
keep if sex == 2
foreach var of varlist *	{ 
	rename `var' `var'_f
				}
rename year_f  year
rename house_f house

merge year house using "C:\temp\CPS_6207m.dta", unique

rename _merge spouse_found
label var     spouse_found "Exists matched spouse data"
label define  spouse_found 1 "female without spouse" 2 "male without spouse" 3 "couple"
label values  spouse_found spouse_found

* drop problematic couples - two heads or two spouses, more than one family, inconsistent marital status or children
drop if relation_m == relation_f                             & spouse_found == 3
drop if (famnum_m  != famnum_f  | fampos_m != fampos_f)      & spouse_found == 3
drop if (marstat_m != marstat_f | child18_m != child18_f)    & spouse_found == 3
drop if child6_m != child6_f & (year >= 1963 & year <= 1967) & spouse_found == 3
drop if child6_m != child6_f & (year >= 1976 & year <= 2007) & spouse_found == 3

tab spouse_found

compress
save "C:\Documents and Settings\Tali\My Documents\Female Labor Supply - Eckstein and Lifshitz\data files\CPS_march_6207_couples.dta", replace

log close
