
capture log close
drop _all

*************************************************************************
*****  This file creates individuals' records from the CPS file		*
*****  for 1962 - 2007.							*
*****  Input files: CPS_march_6207_raw.dta
*****  Output file: CPS_march_6207_ind.dta				*
*************************************************************************

set more 1
set mem 800m 


log using "c:\cpslog1.log", replace

use "C:\Documents and Settings\Tali\My Documents\Female Labor Supply - Eckstein and Lifshitz\data files\CPS_march_6207_raw.dta", clear

* rename variables
rename _marstat	marstat
rename _wkslyr  weeks
rename _clslyr	class
rename _esr	emp_stat

rename _relhd   relation
rename _child6  child6
rename _child18 child18

* keep only one sample per year
* 1988b is processed using the 1989+ method
* 2001s is the expanded sample
drop 	if _year  == "1988b"
drop 	if _year  == " 2001"
replace	_year 	  = "2001" if _year == "2001s"
gen	year = real(_year)
drop 	_year
label var year "Survey year"

* keep only civilian adults (drop armed forces and children)
keep 	if _popstat == 1

drop 	_popstat




* complete missing values
replace	wgt     = 0 if wgt     == .
replace weeks   = 0 if weeks   == .
replace ftpt    = 0 if ftpt    == 5 | ftpt == 9  | ftpt == .
replace class   = 0 if class   == 6 | class == 9 | class == .
replace incwag  = 0 if incwag  == .
replace incer1  = 0 if incer1  == .
replace incwg1  = 0 if incwg1  == .
replace child6  = 0 if child6  == . & year >= 1963 & year <= 1967
replace child18 = 0 if child18 == . & year >= 1963
replace hours   = 0 if hours   == . | hours == -1 | hours == 100
replace hours   = 0 if hours   == 99 & year >= 1963 & year <= 1967

* complete employment status for 1994



replace	emp_stat = 1 if  mlr == 1             & year == 1994


replace	emp_stat = 2 if  mlr == 2             & year == 1994


replace	emp_stat = 3 if (mlr == 3 | mlr == 4) & year == 1994
replace	emp_stat = 7 if  mlr >= 5 & mlr <= 7  & year == 1994


drop mlr
label var    emp_stat "Employment status last week"
label define emp_stat 1 "EMP" 2 "ABSENT" 3 "UNEMP" 7 "OLF"
label values emp_stat emp_stat

* update marital status - join Married spouse present and Married spouse absent
replace marstat = 1 if marstat == 2
label define marstat 1 "Married (inc. spouse absent)" 3 "Separated" 4 "Widowed" 5 "Divorced" 6 "Never married"
label values marstat marstat

* label relation to head of houeshold
label define relation 1 "Head or primary individual" 3 "Spouse" 4 "Child or other relative" 5 "Secondary family member" 6 "Partner / roommate" 7 "Secondary individual"
label values relation relation

* generate education groups
* until 1991, use years of education completed and add 0.5 year if didn't complete highest grade attended
replace grdcom = 1 if grdcom == 6
replace grdcom = 2 if grdcom == 7
replace grdcom = 3 if grdcom == 9
replace _educ  = _educ + 0.5 if grdcom == 2
gen	educ   = 1 if _educ <= 11.5
replace educ   = 2 if _educ == 12
replace educ   = 3 if _educ >= 12.5 & _educ <= 15.5
replace educ   = 4 if _educ >= 16   & _educ <= 17.5
replace educ   = 5 if _educ >= 18   & _educ != .
* from 1992, use educational attainment

replace educ   = 1 if grdatn <= 38


replace educ   = 2 if grdatn == 39
replace educ   = 3 if grdatn >= 40 & grdatn <= 42
replace educ   = 4 if grdatn == 43

replace educ   = 5 if grdatn >= 44 & grdatn != .
drop    grdcom _educ grdatn
label var educ "Education group"
label define educ 1 "HSD" 2 "HSG" 3 "SC" 4 "CG" 5 "PC"
label values educ educ

* generate education group dummies
gen hsd = (educ == 1)
gen hsg = (educ == 2)
gen sc  = (educ == 3)
gen cg  = (educ == 4)
gen pc  = (educ == 5)
label var hsd "HSD?"
label var hsg "HSG?"
label var sc  "SC?"
label var cg  "CG?"
label var pc  "PC?"

* generate experience
gen     exp = age - 18 if educ == 1
replace exp = age - 19 if educ == 2
replace exp = age - 22 if educ == 3
replace exp = age - 23 if educ == 4
replace exp = age - 23 if educ == 5
label var exp "Experience (age - schooling)"

* generate cohort, except for top coded and grouped ages
gen     cohort = year - age
replace cohort = 0 if  age == 90 & year >= 1989 & year <= 2001
replace cohort = 0 if  age == 80 & year >= 2002 & year <= 2003
replace cohort = 0 if (age == 80 | age == 85) & year >= 2004
label var cohort "Cohort (Year of birth)"

* generate household ID
gen     house = _hhid         if year <= 1975
replace house = string(hhseq) if year >= 1976
drop    _hhid hhseq
label var house "Household ID"

* generate full time indicator
gen     ft = 0
replace ft = 1 if  ftpt == 2 & year == 1962
replace ft = 1 if  ftpt == 1 & year >= 1963 & year <= 1967
replace ft = 1 if (ftpt == 1 | ftpt == 3) & year >= 1968
drop    ftpt

* generate full time full year indicator
gen     ftfy = 0
replace ftfy = 1 if ft == 1 & weeks >= 40
label var ftfy "Full time full year (35+ hours per week last year, 40+ weeks last year)"
drop    ft

* generate wage top coding indicator
gen     topcode = 0
replace topcode = 1 if incwag == 99900                    & year >= 1962 & year <= 1967
replace topcode = 1 if incwag == 50000                    & year >= 1968 & year <= 1981
replace topcode = 1 if incwag == 75000                    & year >= 1982 & year <= 1984
replace topcode = 1 if incwag == 99999                    & year >= 1985 & year <= 1988
replace topcode = 1 if incwg1 == 99999                    & year >= 1989 & year <= 1995
replace topcode = 1 if incer1 == 99999  & incwag > incwg1 & year >= 1989 & year <= 1995
replace topcode = 1 if incwg1 >= 25000                    & year >= 1996 & year <= 2002
replace topcode = 1 if incer1 >= 150000 & incwag > incwg1 & year >= 1996 & year <= 2002
replace topcode = 1 if incwg1 >= 35000                    & year >= 2003
replace topcode = 1 if incer1 >= 200000 & incwag > incwg1 & year >= 2003
drop incer1 incwg1

* update top coded wages
replace incwag = incwag * 1.75 if topcode == 1 & year <= 1995
drop topcode

* generate annualized wages (for 52 weeks)

gen     annual_wage = incwag * 52 /weeks
replace annual_wage = 0 if annual_wage == .

* generate weekly wage
gen     week_wage = incwag / weeks
replace week_wage = 0 if week_wage == .
drop incwag weeks

* generate hourly wages
gen     hour_wage = week_wage / hours
replace hour_wage = 0 if hour_wage == .






* generate real wages using PCE (personal consumption expenditure) deflators - NIPA Table 2.3.4 (http://www.bea.gov/bea/dn/nipaweb/index.asp)
* wages refer to last year, so PCE of year X-1 is used for observations of year X
gen     pce = 18.3   if year == 1962
replace pce = 18.515 if year == 1963
replace pce = 18.73  if year == 1964
replace pce = 18.998 if year == 1965
replace pce = 19.274 if year == 1966
replace pce = 19.762 if year == 1967
replace pce = 20.263 if year == 1968
replace pce = 21.06  if year == 1969
replace pce = 22.023 if year == 1970
replace pce = 23.063 if year == 1971
replace pce = 24.045 if year == 1972
replace pce = 24.877 if year == 1973
replace pce = 26.232 if year == 1974
replace pce = 28.944 if year == 1975
replace pce = 31.354 if year == 1976
replace pce = 33.092 if year == 1977
replace pce = 35.239 if year == 1978
replace pce = 37.714 if year == 1979
replace pce = 41.037 if year == 1980
replace pce = 45.414 if year == 1981
replace pce = 49.462 if year == 1982
replace pce = 52.199 if year == 1983
replace pce = 54.446 if year == 1984
replace pce = 56.503 if year == 1985
replace pce = 58.37  if year == 1986
replace pce = 59.794 if year == 1987
replace pce = 61.868 if year == 1988
replace pce = 64.317 if year == 1989
replace pce = 67.122 if year == 1990
replace pce = 70.197 if year == 1991
replace pce = 72.744 if year == 1992
replace pce = 74.841 if year == 1993
replace pce = 76.568 if year == 1994
replace pce = 78.181 if year == 1995
replace pce = 79.858 if year == 1996
replace pce = 81.576 if year == 1997
replace pce = 82.951 if year == 1998
replace pce = 83.696 if year == 1999
replace pce = 85.088 if year == 2000
replace pce = 87.203 if year == 2001
replace pce = 89.029 if year == 2002
replace pce = 90.292 if year == 2003
replace pce = 92.084 if year == 2004
replace pce = 94.521 if year == 2005
replace pce = 97.308 if year == 2006
replace pce = 100    if year == 2007
label var pce "PCE, base year is 2006"
gen real_annual_wage = annual_wage / pce * 100
gen real_week_wage   = week_wage   / pce * 100
gen real_hour_wage   = hour_wage   / pce * 100
label var real_annual_wage "Annualized real wage (for 52 weeks), top coded wages until 1995 updated"
label var real_week_wage   "Weekly wage, top coded wages until 1995 updated"
label var real_hour_wage   "Hourly real wage (using hours last week), top coded wages until 1995 updated"
drop annual_wage week_wage hour_wage





compress

save "C:\Documents and Settings\Tali\My Documents\Female Labor Supply - Eckstein and Lifshitz\data files\CPS_march_6207_ind.dta", replace

log close
