
capture log close
drop _all

*************************************************************************
*****  This file completes the number of children under 6 for years	*
*****  1968 - 1975. We use the distribution of child6 in years 1967	*
*****  and 1976, separately for each sex, marital status and cohort.	*
*****  Input files: CPS_march_6207_ind.dta				*
*****  Output file: CPS_march_6207_ind.dta				*
*************************************************************************

set more 1
set mem 900m


* calculate the distribution in 1967 and 1976
use "C:\Documents and Settings\Tali\My Documents\Female Labor Supply - Eckstein and Lifshitz\data files\CPS_march_6207_ind.dta", clear
keep year child6 sex marstat cohort wgt
keep if year == 1967 | year == 1976
local i = 0
while `i' <= 6	{
	gen child6`i'_67 = (child6 == `i') if year == 1967
	gen child6`i'_76 = (child6 == `i') if year == 1976
	local i = `i' + 1
		}
sort sex marstat cohort
collapse (mean) child60_67 - child66_76 [fw=wgt] if wgt >= 0, by(sex marstat cohort)
save "c:\temp\child6_means", replace

* complete values in 1968 - 1975
use "C:\Documents and Settings\Tali\My Documents\Female Labor Supply - Eckstein and Lifshitz\data files\CPS_march_6207_ind.dta", clear
keep year child6 sex marstat cohort recnum
sort sex marstat cohort
merge sex marstat cohort using "c:\temp\child6_means"
local i = 0
while `i' <= 6	{
	gen child6`i' = (child6 == `i') if child6 != .
	local j = 1
	local y = 1968
	while `j' <= 8	{
		replace child6`i' = child6`i'_67 + (child6`i'_76 - child6`i'_67) / 9 * `j' if year == `y' & child6`i' == .
		local j = `j' + 1
		local y = `y' + 1
			}
	local i = `i' + 1
		}
replace child6 = 0 * child60 + 1 * child61 + 2 * child62 + 3 * child63 + 4 * child64 + 5 * child65 + 6 * child66 if year >= 1968 & year <= 1975 & child6 == .
drop child60_67 - child66_76 _merge sex marstat cohort
sort year recnum
save "c:\temp\child6", replace

use "C:\Documents and Settings\Tali\My Documents\Female Labor Supply - Eckstein and Lifshitz\data files\CPS_march_6207_ind.dta", clear
sort year recnum
drop child6
merge year recnum using "c:\temp\child6", unique
drop recnum _merge

* generate number of old children
gen child618 = child18 - child6

label var child6   "Children under 6 (6 is 6+), completed for 1968 - 1975 (use with caution)"
label var child60  "0  children under 6, probability for 1968 - 1975, dummy otherwise"
label var child61  "1  child    under 6, probability for 1968 - 1975, dummy otherwise"
label var child62  "2  children under 6, probability for 1968 - 1975, dummy otherwise"
label var child63  "3  children under 6, probability for 1968 - 1975, dummy otherwise"
label var child64  "4  children under 6, probability for 1968 - 1975, dummy otherwise"
label var child65  "5  children under 6, probability for 1968 - 1975, dummy otherwise"
label var child66  "6+ children under 6, probability for 1968 - 1975, dummy otherwise"
label var child18  "Children under 18 (7 is 7+)"
label var child618 "Children 6-18 (might be wrong if child18 is 7 = 7+)"



compress

save "C:\Documents and Settings\Tali\My Documents\Female Labor Supply - Eckstein and Lifshitz\data files\CPS_march_6207_ind.dta", replace
