
capture log close
drop _all

*************************************************************************
*****  This file lists aggregated moments and cohort distribution,	*
*****  for comparison with the simulation results.			*
*****  Input file:  CPS_march_6207_ind.dta				*
*************************************************************************

set more 1
set mem 650m 


use "C:\Documents and Settings\Tali\My Documents\Female Labor Supply - Eckstein and Lifshitz\data files\CPS_march_6207_ind.dta", clear

* keep relavant population - women aged 23(or 24)-54 from 1980
keep if sex == 2 & age <= 54 & year >= 1980
keep if (educ <= 3 & age >= 23) | (educ >= 4 & age >= 24)

* keep relevant variables
keep year cohort marstat emp_stat wgt

* generate cohort group dummies
gen cohort_g_bef_27 = (                 cohort <= 1927)
gen cohort_g_28_32  = (cohort >= 1928 & cohort <= 1932)
gen cohort_g_33_37  = (cohort >= 1933 & cohort <= 1937)
gen cohort_g_38_42  = (cohort >= 1938 & cohort <= 1942)
gen cohort_g_43_47  = (cohort >= 1943 & cohort <= 1947)
gen cohort_g_48_52  = (cohort >= 1948 & cohort <= 1952)
gen cohort_g_53_57  = (cohort >= 1953 & cohort <= 1957)
gen cohort_g_58_62  = (cohort >= 1958 & cohort <= 1962)
gen cohort_g_63_67  = (cohort >= 1963 & cohort <= 1967)
gen cohort_g_68_72  = (cohort >= 1968 & cohort <= 1972)
gen cohort_g_73_on  = (cohort >= 1973                 )

* generate marital status dummy
gen married = (marstat <= 2)

* generate employment status dummies
gen par = (emp_stat <= 3)
gen emp = (emp_stat <= 2)

save "c:\temp\aggregated.dta", replace

* cohort distribution and marriage rate
collapse (mean) cohort_g* married [fw = wgt], by(year)
outsheet year cohort_g* married using "C:\Documents and Settings\Tali\My Documents\Female Labor Supply - Eckstein and Lifshitz\section 3\out\pop_distribution.out", replace nolabel nonames

* cohort distribution for married and nonmarried
use "c:\temp\aggregated.dta", clear
collapse (mean) cohort_g* [fw = wgt], by(year married)
outsheet year cohort_g* if married == 1 using "C:\Documents and Settings\Tali\My Documents\Female Labor Supply - Eckstein and Lifshitz\section 3\out\pop_distribution_married.out", replace nolabel nonames
outsheet year cohort_g* if married == 0 using "C:\Documents and Settings\Tali\My Documents\Female Labor Supply - Eckstein and Lifshitz\section 3\out\pop_distribution_nonmarried.out", replace nolabel nonames

* participation and employment rates
use "c:\temp\aggregated.dta", clear
collapse (mean) par emp [fw = wgt], by(year)
outsheet year par emp using "C:\Documents and Settings\Tali\My Documents\Female Labor Supply - Eckstein and Lifshitz\section 3\out\par_emp_rates.out", replace nolabel nonames

* participation and employment rates for married and nonmarried
use "c:\temp\aggregated.dta", clear
collapse (mean) par emp [fw = wgt], by(year married)
outsheet year par emp if married == 1 using "C:\Documents and Settings\Tali\My Documents\Female Labor Supply - Eckstein and Lifshitz\section 3\out\par_emp_rates_married.out", replace nolabel nonames
outsheet year par emp if married == 0 using "C:\Documents and Settings\Tali\My Documents\Female Labor Supply - Eckstein and Lifshitz\section 3\out\par_emp_rates_nonmarried.out", replace nolabel nonames
