
capture log close
drop _all

*************************************************************************
*****  This file lists husbands moments for each cohort.		*
*****  Input file:  CPS_march_6207_couples.dta				*
*************************************************************************

set more 1
set mem 650m 


use "C:\Documents and Settings\Tali\My Documents\Female Labor Supply - Eckstein and Lifshitz\data files\CPS_march_6207_couples.dta", clear

* generate cohort group
gen     cohort_g = 1925 if cohort_f >= 1923 & cohort_f <= 1927
replace cohort_g = 1930 if cohort_f >= 1928 & cohort_f <= 1932
replace cohort_g = 1935 if cohort_f >= 1933 & cohort_f <= 1937
replace cohort_g = 1940 if cohort_f >= 1938 & cohort_f <= 1942
replace cohort_g = 1945 if cohort_f >= 1943 & cohort_f <= 1947
replace cohort_g = 1950 if cohort_f >= 1948 & cohort_f <= 1952
replace cohort_g = 1955 if cohort_f >= 1953 & cohort_f <= 1957
replace cohort_g = 1960 if cohort_f >= 1958 & cohort_f <= 1962
replace cohort_g = 1965 if cohort_f >= 1963 & cohort_f <= 1967
replace cohort_g = 1970 if cohort_f >= 1968 & cohort_f <= 1972
replace cohort_g = 1975 if cohort_f >= 1973 & cohort_f <= 1977

* keep relavant population - women aged 23(or 24)+ in relevant cohort groups with matched husbands (1964+ to have children and education data)
keep if age_f <= 54 & cohort_g != . & spouse_found == 3 & year >= 1964
keep if (educ_f <= 3 & age_f >= 23) | (educ_f >= 4 & age_f >= 24)

* keep relevant variables
keep age_f cohort_g educ_f educ_m emp_stat_m exp_m wgt_m

* generate education group dummies for men (cummulative distribution)
gen hsd_c_m = (educ_m <= 1)
gen hsg_c_m = (educ_m <= 2)
gen sc_c_m  = (educ_m <= 3)
gen cg_c_m  = (educ_m <= 4)

* generate employment status dummy
gen emp_m = (emp_stat_m <= 2)

* generate experience groups
gen     exp_group_m = 1 if exp_m <= 10
replace exp_group_m = 2 if exp_m >  10 & exp_m <= 20
replace exp_group_m = 3 if exp_m >  20 & exp_m <= 30
replace exp_group_m = 4 if exp_m >  30 & exp_m != .

* generate experience group dummies (cummulative distribution)
gen exp_c_10_m = (exp_group_m <= 1)
gen exp_c_20_m = (exp_group_m <= 2)
gen exp_c_30_m = (exp_group_m <= 3)

* husbands' distribution for each education group
collapse (mean) hsd_c_m hsg_c_m sc_c_m cg_c_m exp_c_10_m exp_c_20_m exp_c_30_m emp_m [fw = wgt_m] if wgt_m >= 0, by(cohort_g educ_f age_f)
foreach cohort in 1925 1930 1935 1940 1945 1950 1955 1960 1965 1970 1975	{
	foreach educ in 1 2 3 4 5	{
		outsheet age_f hsd_c_m hsg_c_m sc_c_m cg_c_m exp_c_10_m exp_c_20_m exp_c_30_m emp_m if educ_f == `educ' & cohort_g == `cohort' using "C:\Documents and Settings\Tali\My Documents\Female Labor Supply - Eckstein and Lifshitz\section 3\out\husbands_`cohort'_`educ'.out", nolabel nonames replace
					}
					}
