
capture log close
drop _all

*************************************************************************
*****  This file lists moments and education distribution for each	*
*****  cohort.								*
*****  Input file:  CPS_march_6207_ind.dta				*
*************************************************************************

set more 1
set mem 650m 


use "C:\Documents and Settings\Tali\My Documents\Female Labor Supply - Eckstein and Lifshitz\data files\CPS_march_6207_ind.dta", clear

* generate cohort group
gen     cohort_g = 1925 if cohort >= 1923 & cohort <= 1927
replace cohort_g = 1930 if cohort >= 1928 & cohort <= 1932
replace cohort_g = 1935 if cohort >= 1933 & cohort <= 1937
replace cohort_g = 1940 if cohort >= 1938 & cohort <= 1942
replace cohort_g = 1945 if cohort >= 1943 & cohort <= 1947
replace cohort_g = 1950 if cohort >= 1948 & cohort <= 1952
replace cohort_g = 1955 if cohort >= 1953 & cohort <= 1957
replace cohort_g = 1960 if cohort >= 1958 & cohort <= 1962
replace cohort_g = 1965 if cohort >= 1963 & cohort <= 1967
replace cohort_g = 1970 if cohort >= 1968 & cohort <= 1972
replace cohort_g = 1975 if cohort >= 1973 & cohort <= 1977

* keep relavant population - women aged 23(or 24)+ in relevant cohort groups (1964+ to have children and education data)
keep if  sex == 2 & age <= 54 & cohort_g != . & year >= 1964
keep if (educ <= 3 & age >= 23) | (educ >= 4 & age >= 24)

* keep relevant variables
keep year age cohort_g educ hsd hsg sc cg pc marstat child6* child18* emp_stat real_hour_wage wgt

* generate marital status dummies
gen married  = (marstat <= 2)
gen divorced = (marstat == 5)

* generate number of children dummies
replace child63 = child63 + child64 + child65 + child66
label var child63 "3+ children under 6, probability for 1968 - 1975, dummy otherwise"
gen child618_0 = (child618 == 0)
gen child618_1 = (child618 >  0 & child618 <= 1)
gen child618_2 = (child618 >  1 & child618 <= 2)
gen child618_3 = (child618 >  2 & child618 != .)
replace child618_0 = . if child618 == .
replace child618_1 = . if child618 == .
replace child618_2 = . if child618 == .
replace child618_3 = . if child618 == .
gen child18_0  = (child18 == 0)
gen child18_1  = (child18 == 1)
gen child18_2  = (child18 == 2)
gen child18_3  = (child18 >  2 & child18 != .)

* generate participation and employment dummies
gen     par         = (emp_stat <= 3)
gen     par_marr    = 1 if emp_stat <= 3 & married == 1
replace par_marr    = 0 if emp_stat >  3 & married == 1
gen     par_nonmarr = 1 if emp_stat <= 3 & married == 0
replace par_nonmarr = 0 if emp_stat >  3 & married == 0
gen     emp         = (emp_stat <= 2)
gen     emp_marr    = 1 if emp_stat <= 2 & married == 1
replace emp_marr    = 0 if emp_stat >  2 & married == 1
gen     emp_nonmarr = 1 if emp_stat <= 2 & married == 0
replace emp_nonmarr = 0 if emp_stat >  2 & married == 0

* generate real hourly wage for employed people with non-zero wage
gen hour_wage_nonzero = real_hour_wage if emp_stat <= 1 & real_hour_wage != 0

* keep relevant variables
keep year age cohort_g educ hsd hsg sc cg pc child60-child63 wgt married - hour_wage_nonzero


save "c:\temp\estimation_ind.dta", replace

* moments for each education group in separate files
collapse (mean) par emp married divorced child60 child61 child62 child63 child618_0 child618_1 child618_2 child618_3 hour_wage_nonzero par_marr par_nonmarr emp_marr emp_nonmarr [fw = wgt], by(cohort_g educ age)
foreach cohort in 1925 1930 1935 1940 1945 1950 1955 1960 1965 1970 1975	{
	foreach educ in 1 2 3 4 5	{
		outsheet age par emp married divorced child60 child61 child62 child63 child618_0 child618_1 child618_2 child618_3 hour_wage_nonzero par_marr par_nonmarr emp_marr emp_nonmarr if educ == `educ' & cohort_g == `cohort' using "C:\Documents and Settings\Tali\My Documents\Female Labor Supply - Eckstein and Lifshitz\section 3\out\moments_`cohort'_`educ'.out", nolabel nonames replace
					}
					}

* partial moments for each education group in one file
keep cohort_g educ age par* emp* mar*
foreach var of varlist par* emp* mar*	{
	rename `var' `var'_educ_
					}
reshape wide par* emp* mar*, i(cohort_g age) j(educ)
foreach cohort in 1925 1930 1935 1940 1945 1950 1955 1960 1965 1970 1975	{
	outsheet age par_educ_1 par_educ_2 par_educ_3 par_educ_4 par_educ_5 par_marr* par_non* emp_educ_1 emp_educ_2 emp_educ_3 emp_educ_4 emp_educ_5 emp_mar* emp_non* mar* if cohort_g == `cohort' using "C:\Documents and Settings\Tali\My Documents\Female Labor Supply - Eckstein and Lifshitz\section 3\out\moments_`cohort'_1-5.out", nolabel nonames replace
					}

* employment moments for each education group in one file for all cohorts
	outsheet cohort_g age emp_educ_1 emp_educ_2 emp_educ_3 emp_educ_4 emp_educ_5 emp_mar* emp_non* using "C:\Documents and Settings\Tali\My Documents\Female Labor Supply - Eckstein and Lifshitz\section 3\out\moments_allcohorts_1-5.out", nolabel nonames replace

* moments for each education group for married and nonmarried
use "c:\temp\estimation_ind.dta", clear
collapse (mean) par emp divorced child60 child61 child62 child63 child618_0 child618_1 child618_2 child618_3 hour_wage_nonzero [fw = wgt], by(cohort_g educ age married)
foreach cohort in 1925 1930 1935 1940 1945 1950 1955 1960 1965 1970 1975	{
	foreach educ in 1 2 3 4 5	{
		outsheet age par emp divorced child60 child61 child62 child63 child618_0 child618_1 child618_2 child618_3 hour_wage_nonzero if married == 1 & educ == `educ' & cohort_g == `cohort' using "C:\Documents and Settings\Tali\My Documents\Female Labor Supply - Eckstein and Lifshitz\section 3\out\moments_`cohort'_`educ'_married.out", nolabel nonames replace
		outsheet age par emp divorced child60 child61 child62 child63 child618_0 child618_1 child618_2 child618_3 hour_wage_nonzero if married == 0 & educ == `educ' & cohort_g == `cohort' using "C:\Documents and Settings\Tali\My Documents\Female Labor Supply - Eckstein and Lifshitz\section 3\out\moments_`cohort'_`educ'_nonmarried.out", nolabel nonames replace
					}
					}

* moments for all education groups in separate files
use "c:\temp\estimation_ind.dta", clear
collapse (mean) par emp married divorced child60 child61 child62 child63 child618_0 child618_1 child618_2 child618_3 hour_wage_nonzero par_marr par_nonmarr emp_marr emp_nonmarr [fw = wgt], by(cohort_g age)
foreach cohort in 1925 1930 1935 1940 1945 1950 1955 1960 1965 1970 1975	{
		outsheet age par emp married divorced child60 child61 child62 child63 child618_0 child618_1 child618_2 child618_3 hour_wage_nonzero par_marr par_nonmarr emp_marr emp_nonmarr if cohort_g == `cohort' using "C:\Documents and Settings\Tali\My Documents\Female Labor Supply - Eckstein and Lifshitz\section 3\out\moments_`cohort'.out", nolabel nonames replace
					}

* parital moments for all education groups in one file for all cohorts
		outsheet cohort_g age emp emp_marr emp_nonmarr using "C:\Documents and Settings\Tali\My Documents\Female Labor Supply - Eckstein and Lifshitz\section 3\out\moments_allcohorts.out", nolabel nonames replace

* moments for all education groups for married and nonmarried
use "c:\temp\estimation_ind.dta", clear
collapse (mean) par emp divorced child60 child61 child62 child63 child618_0 child618_1 child618_2 child618_3 hour_wage_nonzero [fw = wgt], by(cohort_g age married)
foreach cohort in 1925 1930 1935 1940 1945 1950 1955 1960 1965 1970 1975	{
		outsheet age par emp divorced child60 child61 child62 child63 child618_0 child618_1 child618_2 child618_3 hour_wage_nonzero if married == 1 & cohort_g == `cohort' using "C:\Documents and Settings\Tali\My Documents\Female Labor Supply - Eckstein and Lifshitz\section 3\out\moments_`cohort'_married.out", nolabel nonames replace
		outsheet age par emp divorced child60 child61 child62 child63 child618_0 child618_1 child618_2 child618_3 hour_wage_nonzero if married == 0 & cohort_g == `cohort' using "C:\Documents and Settings\Tali\My Documents\Female Labor Supply - Eckstein and Lifshitz\section 3\out\moments_`cohort'_nonmarried.out", nolabel nonames replace
					}

* education distribution
use "c:\temp\estimation_ind.dta", clear
collapse (mean) hsd hsg sc cg pc [fw = wgt], by(cohort_g age)
foreach cohort in 1925 1930 1935 1940 1945 1950 1955 1960 1965 1970 1975	{
		outsheet age hsd hsg sc cg pc if cohort_g == `cohort' using "C:\Documents and Settings\Tali\My Documents\Female Labor Supply - Eckstein and Lifshitz\section 3\out\distribution_`cohort'.out", nolabel nonames replace
					}

* education distribution in one file for all cohorts
		outsheet cohort_g age hsd hsg sc cg pc using "C:\Documents and Settings\Tali\My Documents\Female Labor Supply - Eckstein and Lifshitz\section 3\out\distribution_allcohorts.out", nolabel nonames replace

* education distribution for married and nonmarried
use "c:\temp\estimation_ind.dta", clear
collapse (mean) hsd hsg sc cg pc [fw = wgt], by(cohort_g age married)
foreach cohort in 1925 1930 1935 1940 1945 1950 1955 1960 1965 1970 1975	{
		outsheet age hsd hsg sc cg pc if married == 1 & cohort_g == `cohort' using "C:\Documents and Settings\Tali\My Documents\Female Labor Supply - Eckstein and Lifshitz\section 3\out\distribution_`cohort'_married.out", nolabel nonames replace
		outsheet age hsd hsg sc cg pc if married == 0 & cohort_g == `cohort' using "C:\Documents and Settings\Tali\My Documents\Female Labor Supply - Eckstein and Lifshitz\section 3\out\distribution_`cohort'_nonmarried.out", nolabel nonames replace
					}

* education distribution for married and nonmarried in one file for all cohorts
		outsheet cohort_g age hsd hsg sc cg pc if married == 1 using "C:\Documents and Settings\Tali\My Documents\Female Labor Supply - Eckstein and Lifshitz\section 3\out\distribution_allcohorts_married.out", nolabel nonames replace
		outsheet cohort_g age hsd hsg sc cg pc if married == 0 using "C:\Documents and Settings\Tali\My Documents\Female Labor Supply - Eckstein and Lifshitz\section 3\out\distribution_allcohorts_nonmarried.out", nolabel nonames replace

* education distribution for women with non-zero wage
use "c:\temp\estimation_ind.dta", clear
collapse (mean) hsd hsg sc cg pc [fw = wgt] if hour_wage_nonzero != ., by(cohort_g age)
foreach cohort in 1925 1930 1935 1940 1945 1950 1955 1960 1965 1970 1975	{
		outsheet age hsd hsg sc cg pc if cohort_g == `cohort' using "C:\Documents and Settings\Tali\My Documents\Female Labor Supply - Eckstein and Lifshitz\section 3\out\distribution_nonzerowage_`cohort'.out", nolabel nonames replace
					}

* education distribution for women with non-zero wage for married and nonmarried
use "c:\temp\estimation_ind.dta", clear
collapse (mean) hsd hsg sc cg pc [fw = wgt] if hour_wage_nonzero != ., by(cohort_g age married)
foreach cohort in 1925 1930 1935 1940 1945 1950 1955 1960 1965 1970 1975	{
		outsheet age hsd hsg sc cg pc if married == 1 & cohort_g == `cohort' using "C:\Documents and Settings\Tali\My Documents\Female Labor Supply - Eckstein and Lifshitz\section 3\out\distribution_nonzerowage_`cohort'_married.out", nolabel nonames replace
		outsheet age hsd hsg sc cg pc if married == 0 & cohort_g == `cohort' using "C:\Documents and Settings\Tali\My Documents\Female Labor Supply - Eckstein and Lifshitz\section 3\out\distribution_nonzerowage_`cohort'_nonmarried.out", nolabel nonames replace
					}
