
capture log close
drop _all

*************************************************************************
*****  This file creates data for figures on cohort effect.		*
*****  Input file:  CPS_march_6207_ind.dta				*
*************************************************************************

set more 1
set mem 650m


use "C:\Documents and Settings\Tali\My Documents\Female Labor Supply - Eckstein and Lifshitz\data files\CPS_march_6207_ind.dta", clear

* keep relavant population - ages 22-65
keep if age >= 22 & age <= 65

* keep relevant cohorts
keep if cohort == 1925 | cohort == 1935 | cohort == 1945 | cohort == 1955 | cohort == 1965 | cohort == 1975

* generate participation indicator
gen participant = (emp_stat <= 3)

* generate employment indicator
gen employed = (emp_stat <= 2 & hours >= 10)

* generate hours last week for employed people
gen hours_nonzero = hours if emp_stat <= 1

* generate marital status groups
gen     marstat_group = 0
replace marstat_group = 1 if marstat == 1
replace marstat_group = 2 if marstat == 6
replace marstat_group = 3 if marstat == 5
label define marstat_group 1 "married" 2 "single" 3 "divorced"
label values marstat_group marstat_group

* keep relevant variables
keep participant employed hours_nonzero year age sex cohort marstat_group child6 child18 educ hsd hsg sc cg pc wgt

save "c:\temp\figures.dta", replace

* participation, employment and hours by cohort and
* by sex
collapse (mean) participant employed hours [fw = wgt] if wgt >= 0, by(sex cohort age)

outsheet sex cohort age participant employed hours using "c:\temp\figs1.out", replace



* by marital status
use "c:\temp\figures.dta", clear

keep if cohort == 1945 | cohort == 1955 | cohort == 1965 | cohort == 1975
collapse (mean) participant employed hours [fw = wgt] if wgt >= 0, by(sex cohort marstat_group age)
outsheet sex marstat_group cohort age participant employed hours if marstat_group != 0 using "c:\temp\figs2.out", replace



* by marital status for families with children
use "c:\temp\figures.dta", clear
keep if cohort == 1945 | cohort == 1955 | cohort == 1965 | cohort == 1975
keep if child6 > 0 & child6 != .
collapse (mean) participant employed hours [fw = wgt] if wgt >= 0, by(sex cohort marstat_group age)
outsheet sex marstat_group cohort age participant employed hours if (marstat_group == 1 | marstat_group == 3) using "c:\temp\figs3.out", replace


use "c:\temp\figures.dta", clear
keep if cohort == 1945 | cohort == 1955 | cohort == 1965 | cohort == 1975
keep if child18 > 0 & child18 != .
collapse (mean) participant employed hours [fw = wgt] if wgt >= 0, by(sex cohort marstat_group age)
outsheet sex marstat_group cohort age participant employed hours if (marstat_group == 1 | marstat_group == 3) using "c:\temp\figs4.out", replace



* by education
use "c:\temp\figures.dta", clear
keep if cohort == 1945 | cohort == 1955 | cohort == 1965 | cohort == 1975
keep if year >= 1964
collapse (mean) participant employed hours [fw = wgt] if wgt >= 0, by(sex cohort educ age)
outsheet sex educ cohort age participant employed hours using "c:\temp\figs5.out", replace



* educational composition of population 
use "c:\temp\figures.dta", clear
keep if cohort == 1945 | cohort == 1955 | cohort == 1965 | cohort == 1975
keep if year >= 1964
collapse (mean) hsd hsg sc cg pc [fw = wgt] if wgt >= 0, by(sex cohort age)

outsheet sex cohort age hsd hsg sc cg pc using "c:\temp\figs6.out", replace



* educational composition of married
use "c:\temp\figures.dta", clear

keep if year >= 1964
keep if marstat == 1
collapse (mean) hsd hsg sc cg pc [fw = wgt] if wgt >= 0, by(sex cohort age)
outsheet sex cohort age hsd hsg sc cg pc using "c:\temp\figs7.out", replace

