
capture log close
drop _all

*************************************************************************
*****  This file creates data for figures on households.		*
*****  Input file:  CPS_march_6207_couples.dta				*
*************************************************************************

set more 1
set mem 500m


use "C:\Documents and Settings\Tali\My Documents\Female Labor Supply - Eckstein and Lifshitz\data files\CPS_march_6207_couples.dta", clear

* keep relevant population - married couples
keep if spouse_found == 3 & marstat_m == 1

* keep relavant population - women ages 22-65
keep  if age_f >= 22 & age_f <= 65
count if age_m < 22
count if age_m > 65

* generate participation indicator
drop if emp_stat_m == 0
gen participant_m = (emp_stat_m <= 3)
gen participant_f = (emp_stat_f <= 3)
gen participation_only_M = (participant_m == 1 & participant_f == 0)
gen participation_only_F = (participant_m == 0 & participant_f == 1)
gen participation_both   = (participant_m == 1 & participant_f == 1)
gen participation_none   = (participant_m == 0 & participant_f == 0)

* generate employment indicator
gen employed_m = (emp_stat_m <= 2 & hours_m >= 10)
gen employed_f = (emp_stat_f <= 2 & hours_f >= 10)
gen employment_only_M = (employed_m == 1 & employed_f == 0)
gen employment_only_F = (employed_m == 0 & employed_f == 1)
gen employment_both   = (employed_m == 1 & employed_f == 1)
gen employment_none   = (employed_m == 0 & employed_f == 0)

* generate aggragate hours last week
gen     hours_non_zero_m  = hours_m if emp_stat_m <= 1
replace hours_m           = 0       if emp_stat_m > 1
gen     hours_non_zero_f  = hours_f if emp_stat_f <= 1
replace hours_f           = 0       if emp_stat_f > 1
gen     aggregate_hours   = hours_m + hours_f if hours_m != 0 | hours_f != 0
gen     woman_share_hours = hours_f / aggregate_hours

* generate aggregate weekly wage
gen     week_wage_nonzero_m = real_week_wage_m if real_week_wage_m != 0
gen     week_wage_nonzero_f = real_week_wage_f if real_week_wage_f != 0
gen     aggregate_wage      = real_week_wage_m + real_week_wage_f if real_week_wage_m != 0 | real_week_wage_f != 0
gen     woman_share_wage    = real_week_wage_f / aggregate_wage

* keep relevant variables
keep participation* employment* hours_non_zero_m hours_non_zero_f aggregate_hours woman_share_hours week_wage_nonzero_m week_wage_nonzero_f aggregate_wage woman_share_wage year child6_f child18_f educ* wgt*

save "c:\temp\figures.dta", replace

* all households
collapse (mean) participation_only_M - woman_share_wage [fw = wgt_f] if wgt_f >= 0, by(year)

outsheet using "c:\temp\figs1.out", replace



* households with children
use "c:\temp\figures.dta", clear
keep if child6_f > 0 & child6_f != .
collapse (mean) participation_only_M - woman_share_wage [fw = wgt_f] if wgt_f >= 0, by(year)

outsheet using "c:\temp\figs2.out", replace


use "c:\temp\figures.dta", clear
keep if child18_f > 0 & child18_f != .
collapse (mean) participation_only_M - woman_share_wage [fw = wgt_f] if wgt_f >= 0, by(year)

outsheet using "c:\temp\figs3.out", replace



* by woman's education
use "c:\temp\figures.dta", clear
keep if year >= 1964
collapse (mean) participation_only_M - woman_share_wage [fw = wgt_f] if wgt_f >= 0, by(educ_f year)
outsheet using "c:\temp\figs4.out", replace

