
capture log close
drop _all

*************************************************************************
*****  This file creates data for figures on human capital.		*
*****  Input file:  CPS_march_6207_ind.dta				*
*************************************************************************

set more 1
set mem 650m


use "C:\Documents and Settings\Tali\My Documents\Female Labor Supply - Eckstein and Lifshitz\data files\CPS_march_6207_ind.dta", clear

* keep relavant population - ages 22-65
keep if age >= 22 & age <= 65

* keep relevant years (where data on education exists)
keep if year >= 1964

* generate participation indicator
gen participant = (emp_stat <= 3)

* generate employment indicator
gen employed = (emp_stat <= 2 & hours >= 10)

* generate hours last week for employed people
gen hours_nonzero = hours if emp_stat <= 1

* keep relevant variables
keep participant employed hours_nonzero year sex marstat educ hsd hsg sc cg pc wgt

save "c:\temp\figures.dta", replace

* educational composition of population 
collapse (mean) hsd hsg sc cg pc [fw = wgt] if wgt >= 0, by(sex year)

outsheet using "c:\temp\figs1.out", replace



* educational composition of married
use "c:\temp\figures.dta", clear

keep if marstat == 1
collapse (mean) hsd hsg sc cg pc [fw = wgt] if wgt >= 0, by(sex year)
outsheet using "c:\temp\figs2.out", replace



* educational composition of single
use "c:\temp\figures.dta", clear

keep if marstat == 6
collapse (mean) hsd hsg sc cg pc [fw = wgt] if wgt >= 0, by(sex year)
outsheet using "c:\temp\figs3.out", replace



* education composition of non married
use "c:\temp\figures.dta", clear

keep if marstat != 1
collapse (mean) hsd hsg sc cg pc [fw = wgt] if wgt >= 0, by(sex year)
outsheet using "c:\temp\figs4.out", replace



* participation, employment and hours by education
use "c:\temp\figures.dta", clear
collapse (mean) participant employed hours [fw = wgt] if wgt >= 0, by(sex educ year)
outsheet using "c:\temp\figs5.out", replace



* participation, employment and hours of married by education
use "c:\temp\figures.dta", clear
keep if marstat == 1
collapse (mean) participant employed hours [fw = wgt] if wgt >= 0, by(sex educ year)
outsheet using "c:\temp\figs6.out", replace


