
capture log close
drop _all

***************************************************************************
*****  This file creates data for figures on marital status and children. *
*****  Input file:  CPS_march_6207_ind.dta				  *
***************************************************************************

set more 1
set mem 650m


use "C:\Documents and Settings\Tali\My Documents\Female Labor Supply - Eckstein and Lifshitz\data files\CPS_march_6207_ind.dta", clear

* keep relavant population - ages 22-65
keep if age >= 22 & age <= 65

* generate marital status dummies
gen married       = (marstat == 1)
gen never_married = (marstat == 6)
gen divorced      = (marstat == 5)
gen separated     = (marstat == 3)
gen widowed       = (marstat == 4)

* generate number of children dummies
replace child64 = child64 + child65 + child66
gen child18_0  = (child18 == 0)
gen child18_1  = (child18 == 1)
gen child18_2  = (child18 == 2)
gen child18_3  = (child18 == 3)
gen child18_4  = (child18 >= 4 & child18 != .)

* keep relevant variables
keep married - widowed child* year sex age cohort wgt

save "c:\temp\figures.dta", replace

* marital status composition and number of children
collapse (mean) married - widowed child60 child61 child62 child63 child64 child18_0 - child18_4 child6 child18 [fw = wgt] if wgt >= 0, by(sex year)

outsheet using "c:\temp\figs1.out", replace



* number of children of married
use "c:\temp\figures.dta", clear

keep if married == 1
collapse (mean) child60 child61 child62 child63 child64 child18_0 - child18_4 child6 child18 [fw = wgt] if wgt >= 0, by(sex year)
outsheet using "c:\temp\figs2.out", replace



* number of children by cohort
use "c:\temp\figures.dta", clear
keep if cohort == 1925 | cohort == 1935 | cohort == 1945 | cohort == 1955 | cohort == 1965 | cohort == 1975
keep if year >= 1963
keep child6 child18 sex cohort age wgt
collapse (mean) child6 child18 [fw = wgt] if wgt >= 0, by(sex cohort age)

outsheet sex cohort age child6 child18  using "c:\temp\figs3.out", replace



* number of children of married by cohort
use "c:\temp\figures.dta", clear
keep if married == 1
keep if cohort == 1925 | cohort == 1935 | cohort == 1945 | cohort == 1955 | cohort == 1965 | cohort == 1975
keep if year >= 1963
keep child6 child18 sex cohort age wgt
collapse (mean) child6 child18 [fw = wgt] if wgt >= 0, by(sex cohort age)

outsheet sex cohort age child6 child18  using "c:\temp\figs4.out", replace



