
capture log close
drop _all

*************************************************************************
*****  This file creates data for figures on participation rates, 	*
*****  employment rates and number of hours.				*
*****  Input file:  CPS_march_6207_ind.dta				*
*************************************************************************

set more 1
set mem 650m


use "C:\Documents and Settings\Tali\My Documents\Female Labor Supply - Eckstein and Lifshitz\data files\CPS_march_6207_ind.dta", clear

* keep relavant population - ages 22-65
keep if age >= 22 & age <= 65

* generate participation indicator
gen participant = (emp_stat <= 3)

* generate employment indicator
gen employed = (emp_stat <= 2 & hours >= 10)

* generate hours last week for employed people
gen hours_nonzero = hours if emp_stat <= 1

* generate marital status groups
gen     marstat_group = 0
replace marstat_group = 1 if marstat == 1
replace marstat_group = 2 if marstat == 6
replace marstat_group = 3 if marstat == 5
label define marstat_group 1 "married" 2 "single" 3 "divorced"
label values marstat_group marstat_group

* generate number of children groups
gen     child6_group  = 0
replace child6_group  = 1 if child6  == 0
replace child6_group  = 2 if child6  >  0 & child6  <= 1
replace child6_group  = 3 if child6  >  1 & child6  <= 3
replace child6_group  = 4 if child6  >  3 & child6  != .
gen     child18_group = 0
replace child18_group = 1 if child18 == 0
replace child18_group = 2 if child18 >  0 & child18 <= 1
replace child18_group = 3 if child18 >  1 & child18 <= 3
replace child18_group = 4 if child18 >  3 & child18 != .
label define child_group 1 "0" 2 "1" 3 "2-3" 4 "4+"
label values child6_group  child_group
label values child18_group child_group

* keep relevant variables
keep participant employed hours_nonzero year sex marstat_group child6 child6_group child18 child18_group wgt

save "c:\temp\figures.dta", replace

* calculate means for various groups in each year
* by sex
collapse (mean) participant employed hours [fw = wgt] if wgt >= 0, by(sex year)

outsheet using "c:\temp\figs1.out", replace



* by marital status
use "c:\temp\figures.dta", clear

collapse (mean) participant employed hours [fw = wgt] if wgt >= 0, by(sex marstat_group year)
outsheet sex marstat_group year participant employed hours if marstat_group != 0 using "c:\temp\figs2.out", replace



* by marital status for families with children
use "c:\temp\figures.dta", clear
keep if child6 > 0 & child6 != .
collapse (mean) participant employed hours [fw = wgt] if wgt >= 0, by(sex marstat_group year)
outsheet sex marstat_group year participant employed hours if (marstat_group == 1 | marstat_group == 3) using "c:\temp\figs3.out", replace


use "c:\temp\figures.dta", clear
keep if child18 > 0 & child18 != .
collapse (mean) participant employed hours [fw = wgt] if wgt >= 0, by(sex marstat_group year)
outsheet sex marstat_group year participant employed hours if (marstat_group == 1 | marstat_group == 3) using "c:\temp\figs4.out", replace



* by number of children for married
use "c:\temp\figures.dta", clear
keep if marstat_group == 1
collapse (mean) participant employed hours [fw = wgt] if wgt >= 0, by(sex child6_group year)
outsheet sex child6_group year participant employed hours if child6_group != 0 using "c:\temp\figs5.out", replace


use "c:\temp\figures.dta", clear
keep if marstat_group == 1
collapse (mean) participant employed hours [fw = wgt] if wgt >= 0, by(sex child18_group year)
outsheet sex child18_group year participant employed hours if child18_group != 0 using "c:\temp\figs6.out", replace


