
capture log close
drop _all

*************************************************************************
*****  This file creates data for figures on wages.			*
*****  Input file:  CPS_march_6207_ind.dta				*
*************************************************************************

set more 1
set mem 650m


use "C:\Documents and Settings\Tali\My Documents\Female Labor Supply - Eckstein and Lifshitz\data files\CPS_march_6207_ind.dta", clear

* keep relavant population - ages 22-65
keep if age >= 22 & age <= 65

* generate hourly wage for employed people, employed people only in private and government, employed people with non-zero wage, and employed people with wage above the minimum wage
gen hour_wage         = real_hour_wage if emp_stat <= 1
gen hour_wage_class12 = real_hour_wage if emp_stat <= 1 & (class == 1 | class == 2)
gen hour_wage_nonzero = real_hour_wage if emp_stat <= 1 & real_hour_wage != 0
gen hour_wage_minimum = real_hour_wage if emp_stat <= 1 & real_hour_wage >= 1

* generate weekly wage for all, people with non-zero wage, and people with wage above the minimum wage
gen week_wage         = real_week_wage
gen week_wage_nonzero = real_week_wage if real_week_wage != 0
gen week_wage_minimum = real_week_wage if real_week_wage >= 35

* generate annual wage for all, only in private and government, people with non-zero wage, people with wage above the minimum wage, and full time full year workers
gen annual_wage              = real_annual_wage
gen annual_wage_class12      = real_annual_wage if class == 1 | class == 2
gen annual_wage_nonzero      = real_annual_wage if real_annual_wage != 0
gen annual_wage_minimum      = real_annual_wage if real_annual_wage >= 35*40
gen annual_wage_ftfy         = real_annual_wage if                             ftfy == 1
gen annual_wage_ftfy_class12 = real_annual_wage if (class == 1 | class == 2) & ftfy == 1 
gen annual_wage_nonzero_ftfy = real_annual_wage if real_annual_wage != 0     & ftfy == 1
gen annual_wage_minimum_ftfy = real_annual_wage if real_annual_wage >= 35*40 & ftfy == 1

* keep relevant variables
keep hour_wage* week_wage* annual_wage* year sex wgt

save "c:\temp\figures.dta", replace

* by sex
collapse (mean) hour_wage* week_wage* annual_wage* [fw = wgt] if wgt >= 0, by(sex year)

outsheet using "c:\temp\figs1.out", replace


