
capture log close
drop _all

*************************************************************************
*****  This file creates data for figures on women's participation,	*
*****  employment, hours and wages by husbands' wages.			*
*****  Input file:  CPS_march_6207_couples.dta				*
*************************************************************************

set more 1
set mem 500m


use "C:\Documents and Settings\Tali\My Documents\Female Labor Supply - Eckstein and Lifshitz\data files\CPS_march_6207_couples.dta", clear

* keep relevant population - married couples
keep if spouse_found == 3 & marstat_m == 1

* keep relevant cohorts
keep if cohort_f == 1945 | cohort_f == 1955 | cohort_f == 1965 | cohort_f == 1975

* keep relavant population - women ages 22-65
keep if age_f >= 22 & age_f <= 65

* generate participation indicator
gen participant_f = (emp_stat_f <= 3)

* generate employment indicator
gen employed_f = (emp_stat_f <= 2 & hours_f >= 10)

* generate hours last week for employed people
gen     hours_non_zero_f  = hours_f if emp_stat_f <= 1
replace hours_f           = 0       if emp_stat_f > 1

* generate hourly wage for employed people with non-zero wage
gen     hour_wage_nonzero_m = real_hour_wage_m if emp_stat_m <= 1 & real_hour_wage_m != 0
gen     hour_wage_nonzero_f = real_hour_wage_f if emp_stat_f <= 1 & real_hour_wage_f != 0
replace real_hour_wage_f    = 0                if emp_stat_f >  1 

* generate deciles by hourly wage for employed husbands with non zero wage
xtile   decile_1945   = hour_wage_nonzero_m if cohort_f == 1945 [fw = wgt_f], nq(10)
xtile   decile_1955   = hour_wage_nonzero_m if cohort_f == 1955 [fw = wgt_f], nq(10)
xtile   decile_1965   = hour_wage_nonzero_m if cohort_f == 1965 [fw = wgt_f], nq(10)
xtile   decile_1975   = hour_wage_nonzero_m if cohort_f == 1975 [fw = wgt_f], nq(10)
gen     decile_hourly = decile_1945         if cohort_f == 1945
replace decile_hourly = decile_1955         if cohort_f == 1955
replace decile_hourly = decile_1965         if cohort_f == 1965
replace decile_hourly = decile_1975         if cohort_f == 1975
replace decile_hourly = 0                   if decile_hourly == .
drop decile_1945 - decile_1975
label define decile 0 "zero wage (inc. not employed)"
label values decile_hourly decile

* generate number of children groups
gen     child6_group  = 0
replace child6_group  = 1 if child6_f  == 0
replace child6_group  = 2 if child6_f  >  0 & child6_f  <= 1
replace child6_group  = 3 if child6_f  >  1 & child6_f  <= 3
replace child6_group  = 4 if child6_f  >  3 & child6_f  != .
gen     child18_group = 0
replace child18_group = 1 if child18_f == 0
replace child18_group = 2 if child18_f >  0 & child18_f <= 1
replace child18_group = 3 if child18_f >  1 & child18_f <= 3
replace child18_group = 4 if child18_f >  3 & child18_f != .
label define child_group 1 "0" 2 "1" 3 "2-3" 4 "4+"
label values child6_group  child_group
label values child18_group child_group

* keep relevant variables
keep participant employed hours_non_zero_f hours_f hour_wage_nonzero_f real_hour_wage_f cohort_f decile* child6_group child18_group year educ_f age_f wgt*

save "c:\temp\figures.dta", replace

* all households
collapse (mean) participant_f employed_f hours_non_zero_f hours_f hour_wage_nonzero_f real_hour_wage_f [fw = wgt_f] if wgt_f >= 0, by(cohort_f decile_hourly)

outsheet using "c:\temp\figs1.out", replace



* households without children
use "c:\temp\figures.dta", clear
drop if year >= 1968 & year <= 1975
keep if child6_group == 1
collapse (mean) participant_f [fw = wgt_f] if wgt_f >= 0, by(cohort_f decile_hourly)

outsheet using "c:\temp\figs2.out", replace


use "c:\temp\figures.dta", clear
keep if child18_group == 1
collapse (mean) participant_f [fw = wgt_f] if wgt_f >= 0, by(cohort_f decile_hourly)

outsheet using "c:\temp\figs3.out", replace



* households with children
use "c:\temp\figures.dta", clear
drop if year >= 1968 & year <= 1975
keep if child6_group > 1
collapse (mean) participant_f [fw = wgt_f] if wgt_f >= 0, by(cohort_f decile_hourly)

outsheet using "c:\temp\figs4.out", replace


use "c:\temp\figures.dta", clear
keep if child18_group > 1
collapse (mean) participant_f [fw = wgt_f] if wgt_f >= 0, by(cohort_f decile_hourly)

outsheet using "c:\temp\figs5.out", replace



* by number of children
use "c:\temp\figures.dta", clear
drop if year >= 1968 & year <= 1975
collapse (mean) participant_f [fw = wgt_f] if wgt_f >= 0, by(cohort_f child6_group decile_hourly)

outsheet cohort_f child6_group decile_hourly participant_f using "c:\temp\figs6.out", replace


use "c:\temp\figures.dta", clear
collapse (mean) participant_f [fw = wgt_f] if wgt_f >= 0, by(cohort_f child18_group decile_hourly)

outsheet cohort_f child18_group decile_hourly participant_f using "c:\temp\figs7.out", replace



* by woman's education
use "c:\temp\figures.dta", clear
collapse (mean) participant_f [fw = wgt_f] if wgt_f >= 0, by(cohort_f educ_f decile_hourly)
outsheet cohort_f educ_f decile_hourly participant_f using "c:\temp\figs8.out", replace



